@@ -12,7 +12,7 @@ $ zzansi2html _tmp1
 <pre style="background:#000;color:#FFF"><div style="display:inline">
 <span style="color:#0F0;font-weight:normal;text-decoration:none"> verde </div><div style="display:inline">
 </pre>
-$ zzansi2html _tmp3  #→ --file zzansi2html.out.html
+$ zzansi2html _tmp3  #=> --file zzansi2html.out.html
 
 # faxina
 $ rm -f _tmp[123]
