@@ -9,8 +9,8 @@ $ printf '\033[10;750]\033[11;100]'  >> _tmp2
 $ printf 'OK\n'                      >> _tmp2
 $
 
-$ zzbeep                             #→ --file _tmp1
-$ zzbeep 0                           #→ --file _tmp2
+$ zzbeep                             #=> --file _tmp1
+$ zzbeep 0                           #=> --file _tmp2
 
 # faxina
 $ rm -f _tmp[12]
