@@ -11,24 +11,24 @@ $ cat _dados.txt
 $
 
 # Sem argumentos
-$ zzcontapalavra				#→ --regex ^Uso:
+$ zzcontapalavra				#=> --regex ^Uso:
 
 # Uso normal
-$ zzcontapalavra one _dados.txt			#→ 1
-$ zzcontapalavra -i one _dados.txt		#→ 1
+$ zzcontapalavra one _dados.txt			#=> 1
+$ zzcontapalavra -i one _dados.txt		#=> 1
 
 # Conta ambas quando há duas ocorrências na mesma linha
 # (diferente do grep -c)
-$ zzcontapalavra -p o _dados.txt		#→ 6
-$ zzcontapalavra -i -p o _dados.txt		#→ 6
-$ zzcontapalavra -p o -- -_tmp1			#→ 6
-$ zzcontapalavra -i -p o -- -_tmp1		#→ 6
+$ zzcontapalavra -p o _dados.txt		#=> 6
+$ zzcontapalavra -i -p o _dados.txt		#=> 6
+$ zzcontapalavra -p o -- -_tmp1			#=> 6
+$ zzcontapalavra -i -p o -- -_tmp1		#=> 6
 
 # Palavra parcial, mas sem -p
-$ zzcontapalavra o _dados.txt			#→ 0
+$ zzcontapalavra o _dados.txt			#=> 0
 
 # Não conta símbolos
-$ zzcontapalavra : _dados.txt			#→ 0
+$ zzcontapalavra : _dados.txt			#=> 0
 
 # Limpeza
 $ rm -f ./-_tmp1
