@@ -1,10 +1,10 @@
-$ zzferiado		foo		#→ --regex ^Data inválida 
-$ zzferiado		1		#→ --regex ^Data inválida 
-$ zzferiado	-l	foo		#→ --regex ^Ano inválido 
-$ zzferiado	-l	25/12		#→ --regex ^Ano inválido 
+$ zzferiado		foo		#=> --regex ^Data inválida 
+$ zzferiado		1		#=> --regex ^Data inválida 
+$ zzferiado	-l	foo		#=> --regex ^Ano inválido 
+$ zzferiado	-l	25/12		#=> --regex ^Ano inválido 
 
-$ zzferiado		25/12/2008	#→ É feriado: 25/12/2008
-$ zzferiado		26/12/2008	#→ Não é feriado: 26/12/2008
+$ zzferiado		25/12/2008	#=> É feriado: 25/12/2008
+$ zzferiado		26/12/2008	#=> Não é feriado: 26/12/2008
 
 $ zzferiado -l 2010
 01/01 sexta-feira     Confraternização Universal
