@@ -1,3 +1,3 @@
 $ lower='abcdefghijklmnopqrstuvwxyzàáâãäåèéêëìíîïòóôõöùúûüçñ'
 $ upper='ABCDEFGHIJKLMNOPQRSTUVWXYZÀÁÂÃÄÅÈÉÊËÌÍÎÏÒÓÔÕÖÙÚÛÜÇÑ'
-$ zzminusculas "$upper"	#→ --eval echo "$lower"
+$ zzminusculas "$upper"	#=> --eval echo "$lower"
