@@ -1,3 +1,3 @@
 # Exemplo: "Feliz Natal" em Esperanto: Gajan Kristnaskon
 
-$ zznatal  #→ --regex ^"Feliz Natal" em .+: .+$
+$ zznatal  #=> --regex ^"Feliz Natal" em .+: .+$
