@@ -58,6 +58,12 @@ timemania:
  99 99 99 99 99
  99 99 99 99 99
 
+sorte:
+ 99 99 99 99 99 99 99
+
+sete:
+ 9 9 9 9 9 9 9
+
 loteca:
  Jogo 99: Coluna ...
  Jogo 99: Coluna ...
