@@ -8,12 +8,12 @@ $
 
 # Nada a remover
 
-$ zzuniq _dados.txt	#→ --file _dados.txt
+$ zzuniq _dados.txt	#=> --file _dados.txt
 
 # Cada linha aparece 3x
 
 $ cat _dados.txt _dados.txt _dados.txt > _tmp1
-$ zzuniq _tmp1		#→ --file _dados.txt
+$ zzuniq _tmp1		#=> --file _dados.txt
 
 # Faxina
 
