@@ -5,15 +5,14 @@
 #
 # Autor: Thobias Salazar Trevisan, www.thobias.org
 # Desde: 2005-09-01
-# Versão: 5
+# Versão: 6
 # Licença: GPL
+# Tags: internet, consulta
 # ----------------------------------------------------------------------------
 zzipinternet ()
 {
 	zzzz -h ipinternet "$1" && return
 
-	local url='http://ipaddress.com/'
-
 	# O resultado já vem pronto!
-	zztool dump "$url" | sed -n 's/.*Your IP .ddress is: //p'
+	zztool source 'http://api.ipaddress.com/myip' | zztool nl_eof
 }
