@@ -10,6 +10,7 @@
 # Versão: 4
 # Licença: GPL
 # Requisitos: zztrim zzunescape zzxml zzjuntalinhas
+# Tags: internet, consulta
 # ----------------------------------------------------------------------------
 zzrastreamento ()
 {
@@ -17,7 +18,7 @@ zzrastreamento ()
 
 	test -n "$1" || { zztool -e uso rastreamento; return 1; }
 
-	local url='http://www2.correios.com.br/sistemas/rastreamento/resultado_semcontent.cfm?'
+	local url='https://www2.correios.com.br/sistemas/rastreamento/resultado.cfm'
 
 	# Para cada código recebido...
 	for codigo
