@@ -15,6 +15,7 @@
 # Versão: 7
 # Licença: GPL
 # Requisitos: zzunescape zzxml
+# Tags: internet, distração
 # ----------------------------------------------------------------------------
 zzvdp ()
 {
@@ -24,7 +25,10 @@ zzvdp ()
 	local sep='------------------------------------------------------------------------------'
 	local ord=1
 
-	zztool testa_numero "$1" && ord=$1
+	if test -n "$1"
+	then
+		zztool testa_numero "$1" && ord=$1 || { zztool -e uso vdp; return 1; }
+	fi
 
 	zztool source "$url" |
 	awk '
